@@ -12,6 +12,7 @@ Tests currently cover:
     - average - flat forecast of average
     - drift - previous value + gradient 
     - ensemble naive - the average of all of the methods
+    - Test fit_predict()
 
 5. Prediction intervals
     - horizon 
@@ -47,6 +48,21 @@ def test_naive1_forecast_horizon(data, horizon, expected):
     preds = model.predict(horizon)
     assert len(preds) == expected
 
+
+@pytest.mark.parametrize("data, horizon, expected", 
+                         [([1, 2, 3, 4, 5], 12, 12),
+                          ([1, 2, 3, 4, 5], 24, 24),
+                          ([1, 2, 3], 8, 8)
+                          ])
+def test_naive1_fit_predict(data, horizon, expected):
+    '''
+    test the correct number of error metric functions are returned.
+    '''
+    model = b.Naive1()
+    #fit_predict for point forecasts only
+    preds = model.fit_predict(pd.Series(data), horizon)
+    assert len(preds) == expected
+
 @pytest.mark.parametrize("data, horizon, expected", 
                          [([1, 2, 3, 4, 5], 12, 12),
                           ([1, 2, 3, 4, 5], 24, 24),
@@ -63,6 +79,21 @@ def test_snaive_forecast_horizon(data, horizon, expected):
     assert len(preds) == expected
 
 
+@pytest.mark.parametrize("data, horizon, expected", 
+                         [([1, 2, 3, 4, 5], 12, 12),
+                          ([1, 2, 3, 4, 5], 24, 24),
+                          ([1, 2, 3], 8, 8)
+                          ])
+def test_snaive_fit_predict(data, horizon, expected):
+    '''
+    test the correct number of error metric functions are returned.
+    '''
+    model = b.SNaive(1)
+    #fit_predict for point forecasts only
+    preds = model.fit_predict(pd.Series(data), horizon)
+    assert len(preds) == expected
+
+
 @pytest.mark.parametrize("data, horizon, expected", 
                          [([1, 2, 3, 4, 5], 12, 12),
                           ([1, 2, 3, 4, 5], 24, 24),
@@ -79,6 +110,21 @@ def test_drift_forecast_horizon(data, horizon, expected):
     assert len(preds) == expected
 
 
+@pytest.mark.parametrize("data, horizon, expected", 
+                         [([1, 2, 3, 4, 5], 12, 12),
+                          ([1, 2, 3, 4, 5], 24, 24),
+                          ([1, 2, 3], 8, 8)
+                          ])
+def test_drift_fit_predict(data, horizon, expected):
+    '''
+    test the correct number of error metric functions are returned.
+    '''
+    model = b.Drift()
+    #fit_predict for point forecasts only
+    preds = model.fit_predict(pd.Series(data), horizon)
+    assert len(preds) == expected
+
+
 @pytest.mark.parametrize("data, horizon, expected", 
                          [([1, 2, 3, 4, 5], 12, 12),
                           ([1, 2, 3, 4, 5], 24, 24),
@@ -95,6 +141,21 @@ def test_average_forecast_horizon(data, horizon, expected):
     assert len(preds) == expected
 
 
+@pytest.mark.parametrize("data, horizon, expected", 
+                         [([1, 2, 3, 4, 5], 12, 12),
+                          ([1, 2, 3, 4, 5], 24, 24),
+                          ([1, 2, 3], 8, 8)
+                          ])
+def test_average_fit_predict(data, horizon, expected):
+    '''
+    test the correct number of error metric functions are returned.
+    '''
+    model = b.Average()
+    #fit_predict for point forecasts only
+    preds = model.fit_predict(pd.Series(data), horizon)
+    assert len(preds) == expected
+
+
 @pytest.mark.parametrize("data, horizon, expected", 
                          [([1, 2, 3, 4, 5], 12, 12),
                           ([1, 2, 3, 4, 5], 24, 24),
@@ -453,12 +514,12 @@ def test_drift_abnormal_input(data, exception):
         model.fit(data)
 
 
-@pytest.mark.parametrize("data, horizon, alphas, expected", 
+@pytest.mark.parametrize("data, horizon, alpha, expected", 
                          [([1, 2, 3, 4, 5], 12, [0.2, 0.05], 12),
                           ([1, 2, 3, 4, 5], 24, [0.2, 0.10, 0.05], 24),
                           ([1, 2, 3], 8, [0.8], 8)
                           ])
-def test_naive1_pi_horizon(data, horizon, alphas, expected):
+def test_naive1_pi_horizon(data, horizon, alpha, expected):
     '''
     test the correct forecast horizon is returned for prediction interval
     for Naive1
@@ -466,56 +527,56 @@ def test_naive1_pi_horizon(data, horizon, alphas, expected):
     model = b.Naive1()
     model.fit(pd.Series(data))
     #point forecasts only
-    preds, intervals = model.predict(horizon, return_predict_int=True, alphas=alphas)
+    preds, intervals = model.predict(horizon, return_predict_int=True, alpha=alpha)
     assert len(intervals[0]) == expected
 
 
-@pytest.mark.parametrize("data, horizon, alphas, expected", 
+@pytest.mark.parametrize("data, horizon, alpha, expected", 
                          [([1, 2, 3, 4, 5], 12, [0.2, 0.05], 12),
                           ([1, 2, 3, 4, 5], 24, [0.2, 0.10, 0.05], 24),
                           ([1, 2, 3], 8, [0.8], 8)
                           ])
-def test_snaive_pi_horizon(data, horizon, alphas, expected):
+def test_snaive_pi_horizon(data, horizon, alpha, expected):
     '''
     test the correct forecast horizon is returned for prediction interval for SNaive
     '''
     model = b.SNaive(1)
     model.fit(pd.Series(data))
     #point forecasts only
-    preds, intervals = model.predict(horizon, return_predict_int=True, alphas=alphas)
+    preds, intervals = model.predict(horizon, return_predict_int=True, alpha=alpha)
     assert len(intervals[0]) == expected
 
-@pytest.mark.parametrize("data, horizon, alphas, expected", 
+@pytest.mark.parametrize("data, horizon, alpha, expected", 
                          [([1, 2, 3, 4, 5], 12, [0.2, 0.05], 12),
                           ([1, 2, 3, 4, 5], 24, [0.2, 0.10, 0.05], 24),
                           ([1, 2, 3], 8, [0.8], 8)
                           ])
-def test_drift_pi_horizon(data, horizon, alphas, expected):
+def test_drift_pi_horizon(data, horizon, alpha, expected):
     '''
     test the correct forecast horizon is returned for prediction interval for Drift
     '''
     model = b.Drift()
     model.fit(pd.Series(data))
     #point forecasts only
-    preds, intervals = model.predict(horizon, return_predict_int=True, alphas=alphas)
+    preds, intervals = model.predict(horizon, return_predict_int=True, alpha=alpha)
     assert len(intervals[0]) == expected
 
-@pytest.mark.parametrize("data, horizon, alphas, expected", 
+@pytest.mark.parametrize("data, horizon, alpha, expected", 
                          [([1, 2, 3, 4, 5], 12, [0.2, 0.05], 12),
                           ([1, 2, 3, 4, 5], 24, [0.2, 0.10, 0.05], 24),
                           ([1, 2, 3], 8, [0.8], 8)
                           ])
-def test_average_pi_horizon(data, horizon, alphas, expected):
+def test_average_pi_horizon(data, horizon, alpha, expected):
     '''
     test the correct forecast horizon is returned for prediction interval for Average
     '''
     model = b.Average()
     model.fit(pd.Series(data))
     #point forecasts only
-    preds, intervals = model.predict(horizon, return_predict_int=True, alphas=alphas)
+    preds, intervals = model.predict(horizon, return_predict_int=True, alpha=alpha)
     assert len(intervals[0]) == expected
 
-@pytest.mark.parametrize("model, data, horizon, alphas, expected", 
+@pytest.mark.parametrize("model, data, horizon, alpha, expected", 
                          [(b.Naive1(), [1, 2, 3, 4, 5], 12, [0.2, 0.05], 2),
                           (b.Naive1(), [1, 2, 3, 4, 5], 24, [0.2, 0.10, 0.05], 3),
                           (b.SNaive(1), [1, 2, 3], 8, [0.8], 1),
@@ -528,14 +589,14 @@ def test_average_pi_horizon(data, horizon, alphas, expected):
                           (b.Drift(), [1, 2, 3], 8, None, 2),
                           (b.Average(), [1, 2, 3, 4, 5], 24, [0.2, 0.10, 0.05], 3)
                           ])
-def test_naive_pi_set_number(model, data, horizon, alphas, expected):
+def test_naive_pi_set_number(model, data, horizon, alpha, expected):
     '''
     test the correct number of Prediction intervals are
     returned for prediction interval for all Naive forecasting classes
     '''
     model.fit(pd.Series(data))
     #point forecasts only
-    preds, intervals = model.predict(horizon, return_predict_int=True, alphas=alphas)
+    preds, intervals = model.predict(horizon, return_predict_int=True, alpha=alpha)
     assert len(intervals) == expected
 
 
@@ -569,7 +630,7 @@ def test_naive1_prediction_interval_low():
 
     model = b.Naive1()
     model.fit(train)
-    preds, intervals = model.predict(5, return_predict_int=True, alphas=[0.2])
+    preds, intervals = model.predict(5, return_predict_int=True, alpha=[0.2])
     print(intervals[0].T[0])
     assert pytest.approx(intervals[0].T[0], rel=1e-6, abs=0.1) == low
 
@@ -586,7 +647,7 @@ def test_naive1_prediction_interval_high():
 
     model = b.Naive1()
     model.fit(train)
-    preds, intervals = model.predict(5, return_predict_int=True, alphas=[0.2])
+    preds, intervals = model.predict(5, return_predict_int=True, alpha=[0.2])
     
     print(intervals[0].T[1])
     assert pytest.approx(intervals[0].T[1], rel=1e-6, abs=0.1) == high
@@ -619,7 +680,7 @@ def test_average_prediction_interval_high():
 
     model = b.Average()
     model.fit(train)
-    preds, intervals = model.predict(5, return_predict_int=True, alphas=[0.2])
+    preds, intervals = model.predict(5, return_predict_int=True, alpha=[0.2])
     
     print(intervals[0].T[1])
     #assert np.array_equal(intervals[0].T[1], high)
@@ -638,7 +699,7 @@ def test_average_prediction_interval_low():
 
     model = b.Average()
     model.fit(train)
-    preds, intervals = model.predict(5, return_predict_int=True, alphas=[0.2])
+    preds, intervals = model.predict(5, return_predict_int=True, alpha=[0.2])
     
     print(intervals[0].T[1])
     #assert np.array_equal(intervals[0].T[1], high)
@@ -656,7 +717,7 @@ def test_naive1_prediction_interval_95_high():
 
     model = b.Naive1()
     model.fit(train)
-    preds, intervals = model.predict(5, return_predict_int=True, alphas=[0.05])
+    preds, intervals = model.predict(5, return_predict_int=True, alpha=[0.05])
     
     print(intervals[0].T[1])
     assert pytest.approx(intervals[0].T[1], rel=1e-6, abs=0.1) == high
@@ -673,7 +734,7 @@ def test_naive1_prediction_interval_95_low():
 
     model = b.Naive1()
     model.fit(train)
-    preds, intervals = model.predict(5, return_predict_int=True, alphas=[0.05])
+    preds, intervals = model.predict(5, return_predict_int=True, alpha=[0.05])
     
     print(intervals[0].T[0])
     assert pytest.approx(intervals[0].T[0], rel=1e-6, abs=0.1) == low
@@ -692,7 +753,7 @@ def test_snaive_prediction_interval_80_low():
     #quarterly data
     model = b.SNaive(period=4)
     model.fit(train)
-    preds, intervals = model.predict(5, return_predict_int=True, alphas=[0.2])
+    preds, intervals = model.predict(5, return_predict_int=True, alpha=[0.2])
     
     print(intervals[0].T[0])
     assert pytest.approx(intervals[0].T[0]) == low
@@ -710,7 +771,7 @@ def test_snaive_prediction_interval_80_high():
     #quarterly data
     model = b.SNaive(period=4)
     model.fit(train)
-    preds, intervals = model.predict(5, return_predict_int=True, alphas=[0.2])
+    preds, intervals = model.predict(5, return_predict_int=True, alpha=[0.2])
     
     print(intervals[0].T[1])
     assert pytest.approx(intervals[0].T[1]) == high
@@ -729,7 +790,7 @@ def test_snaive_prediction_interval_95_high():
     #quarterly data
     model = b.SNaive(period=4)
     model.fit(train)
-    preds, intervals = model.predict(5, return_predict_int=True, alphas=[0.05])
+    preds, intervals = model.predict(5, return_predict_int=True, alpha=[0.05])
     
     print(intervals[0].T[1])
     assert pytest.approx(intervals[0].T[1]) == high
@@ -747,7 +808,7 @@ def test_snaive_prediction_interval_95_low():
     #quarterly data
     model = b.SNaive(period=4)
     model.fit(train)
-    preds, intervals = model.predict(5, return_predict_int=True, alphas=[0.05])
+    preds, intervals = model.predict(5, return_predict_int=True, alpha=[0.05])
     
     print(intervals[0].T[0])
     assert pytest.approx(intervals[0].T[0]) == low
@@ -765,7 +826,7 @@ def test_drift_prediction_interval_95_low():
     #quarterly data
     model = b.Drift()
     model.fit(train)
-    preds, intervals = model.predict(5, return_predict_int=True, alphas=[0.05])
+    preds, intervals = model.predict(5, return_predict_int=True, alpha=[0.05])
 
     print(intervals[0].T[0])
     #not ideal due to not adjusting for drift i think,
@@ -784,7 +845,7 @@ def test_drift_prediction_interval_95_high():
     #quarterly data
     model = b.Drift()
     model.fit(train)
-    preds, intervals = model.predict(5, return_predict_int=True, alphas=[0.05])
+    preds, intervals = model.predict(5, return_predict_int=True, alpha=[0.05])
 
     print(intervals[0].T[1])
     #not ideal due to not adjusting for drift i think,
@@ -1005,6 +1066,25 @@ def test_average_fitted_values_nan_length():
 
 
 
+def test_snaive_call_predict_before_fit():
+    '''
+    test SNaive raises correct exceptions when
+    predict is called before fit
+    '''
+    model = b.SNaive(7)
+    with pytest.raises(UnboundLocalError):
+        model.predict(10)
+
+
+def test_drift_call_predict_before_fit():
+    '''
+    test Drift raises correct exceptions when
+    predict is called before fit
+    '''
+    model = b.Drift()
+    with pytest.raises(UnboundLocalError):
+        model.predict(10)
+
 
 
 
